@@ -1,5 +1,6 @@
 import io
 import os
+import posixpath
 import sys
 import shutil
 import tempfile
@@ -22,6 +23,10 @@ def read_asset(*paths):
         return file.read().strip()
 
 
+def get_url_relpath(path, current):
+    return posixpath.relpath(path, os.path.dirname(current))
+
+
 def get_relpath(path, current):
     return os.path.relpath(path, os.path.dirname(current))
 
