@@ -25,7 +25,7 @@ class BlogPlugin(Plugin):
     @property
     def relpath(self):
         path = f"{self.path}/index.html"
-        return helpers.get_relpath(path, self.document.path)
+        return helpers.get_url_relpath(path, self.document.path)
 
     @property
     def items(self):
@@ -35,7 +35,7 @@ class BlogPlugin(Plugin):
         index_path = "/".join([self.path, "index"])
         for document in self.document.project.documents:
             if document.path.startswith(self.path) and document.path != index_path:
-                relpath = helpers.get_relpath(document.path, self.document.path)
+                relpath = helpers.get_url_relpath(document.path, self.document.path)
                 items.append({"document": document, "relpath": relpath})
         return items
 
